!============fill the weighted events into the x-Q grid and write into outputs============
!=========================================================================================
      subroutine appinit
c clean the directory and initialize grid weights
      implicit none
      include "grid.inc"

      wgtgrid=0.d0

      call system('if [ -f list.log ]; then rm list.log; fi')
      call system('if [ -f wei.log ]; then rm wei.log; fi')
      call system('for i in sub.*; do if [ -f $i ]; then rm $i;fi; done')

      end subroutine

      subroutine readwgt(fname, fwt)
c read in iteration weight factor from CUBA output
      implicit none
      character*100 fname
      double precision fwt

      open(unit=601, file=fname, status="old", action="read")
      read(601, *) fwt
      close(601)

      end subroutine

      subroutine append(zz)
c combining separate grid weight files for the parellel modes 
      implicit none
      include "grid.inc"
      integer i, j, k, l, r
      double precision total(Nx*Nq, Nx*Nq, 5), xy(5), aux
      character*100 sname(100), zz

      total=0.d0

      call system('if [ -f list.log ]; then rm list.log; fi')
      call system('for i in sub.*; do echo $i >>list.log; done')
      open(unit=901, file="list.log", status="old", action="read")

      i=1
      do while(0.lt.1)
      read(901, *, end=500) sname(i)
      i=i+1
      enddo

 500  close(901)

      do j=1, i-1
      open(unit=902, file=sname(j), status="old", action="read")
      do while(0.lt.1)
      read(902, *, end=800) k, l, xy(1:5)
      do r=1, 5
      total(k, l, r)=total(k, l, r)+xy(r)
      enddo
      enddo
 800  close(902)
      enddo

      open(unit=903, file=zz, status="unknown", position="append")
      write(903, *) "JCC"
      do k=1, Nx
      do l=1, Nx*Nq
      aux=abs(total(k, l, 1))+abs(total(k, l, 2))+abs(total(k, l, 3))
     -    +abs(total(k, l, 4))+abs(total(k, l, 5))
      if(aux.ne.0.d0) then 
      write(903, '(2I4,5ES11.3)') k, l, total(k, l, 1:5)
      endif
      enddo
      enddo
      close(903)

      call system('rm sub.*; rm list.log; rm wei.log')

      end subroutine

      subroutine apphead
c write the header to the final outputs of the grid weights
      implicit none
      integer i
      double precision alphasPDF
      external alphasPDF
      include "var.inc"
      include "grid.inc"

      open(unit=179, file=apwname, status="replace")
      write(179, *) ppcollider, mode, 91.d0, alphasPDF(91.d0) 
      write(179, *) sqrts, ang, scalescheme, Rcone 
      write(179, *) chid, chiu, masscutd, masscutu, mu0 
      write(179, *) Nx, Nq
      do i=1, Nx
      write(179, '(D12.5)') xi(i)
      enddo 
      do i=1, Nq
      write(179, '(D12.5)') qi(i)
      enddo 
      close(179)

      end subroutine

      subroutine appsum(pname)
c write the grid weights for a single-core job
      implicit none
      include "grid.inc"
      integer i, j
      double precision aux
      character*100 pname

      open(unit=427, file=pname, status="unknown")
      do i=1, Nx
      do j=1, Nx*Nq
      aux=abs(wgtgrid(i, j, 1))+abs(wgtgrid(i, j, 2))+abs(wgtgrid(i, j, 3))
     -    +abs(wgtgrid(i, j, 4))+abs(wgtgrid(i, j, 5))
      if(aux.ne.0.d0) then 
      write(427, '(2I8,5D14.6)') i, j, wgtgrid(i, j, 1:5)
      endif
      enddo
      enddo
      close(427)

      end subroutine


      subroutine appfill
c fill the weighted events into the x-Q grid
      implicit none
      integer i, ii, j, jj, k, kk, p, pp, lp1, lp2, lp3
      include "appl.inc"
      include "grid.inc"
      double precision pr1(pint+1), pr2(pint+1), pr3(pint+1)

      lp1=0
      lp2=0
      lp3=0
      pr1=0.d0
      pr2=0.d0
      pr3=0.d0

      do p=1, 30

      if(apmuf(p).eq.0.d0) return

      call XMAP(appdfx, lp1, pr1)
      call XMAP(appdfy, lp2, pr2)
      call QMAP(apmuf(p), lp3, pr3)

      do i=1, pint+1
      do ii=1, pint+1
      do jj=1, pint+1
      k=(lp1+i-1)
      kk=Nq*(lp2+ii-2)+(lp3+jj-1)
      do pp=1, 5
      auxwt(k, kk, pp)=auxwt(k, kk, pp)
     -    +apwgt(pp, p)*pr1(i)*pr2(ii)*pr3(jj)
     -    /appdfx**2/appdfy**2
c  interpolation is on x**2*pdf
      enddo
      enddo
      enddo
      enddo

      enddo

      end subroutine
