!=============QCD spliting functions in dipole subtraction formalism==================
!=====================================================================================
      double precision function psplit(i,j,k,x)
      implicit none
c     splitting kernal p_ij, i,j (0 for gluon, or 1 for quark), k (0 for
c     delta(1-x), 1 for regular part, 2 for plus part(1/(1-x)))      
      double precision x, regps
      integer i,j,k
      external regps
      include "var.inc"

      if((i.eq.0).and.(j.eq.0)) then
         if(k.eq.0) then
              psplit=11.d0/2.d0-nf/3.d0
         elseif(k.eq.1) then
              psplit=regps(i,j,x)    
         elseif(k.eq.2) then
              psplit=2.d0*3.d0
         else 
             print *, "wrong splitting!"
         endif    
      elseif((i.eq.1).and.(j.eq.1)) then
         if(k.eq.0) then
              psplit=2.d0
         elseif(k.eq.1) then
              psplit=regps(i,j,x)     
         elseif(k.eq.2) then
              psplit=8.d0/3.d0
         else 
             print *, "wrong splitting!"
         endif
      else    
         if(k.eq.0) then
              psplit=0.d0
         elseif(k.eq.1) then
              psplit=regps(i,j,x)     
         elseif(k.eq.2) then
              psplit=0.d0
         else 
             print *, "wrong splitting!"
         endif
      endif

      end function

      double precision function regps(i,j,x)
      implicit none
c     regulated splitting kernal p_ij
      double precision x
      integer i,j
      include "var.inc"

      if((i.eq.0).and.(j.eq.0)) then
              regps=2.d0*3.d0*((1.d0-x)/x-1.d0+x*(1.d0-x))
      elseif((i.eq.0).and.(j.eq.1)) then
              regps=(x**2+(1.d0-x)**2)/2.d0
      elseif((i.eq.1).and.(j.eq.0)) then
              regps=4.d0/3.d0*(1.d0+(1.d0-x)**2)/x
      elseif((i.eq.1).and.(j.eq.1)) then
              regps=-4.d0/3.d0*(1.d0+x)
      else
              print *, "wrong splitting!"
      endif

      end function

      double precision function hatps(i,j,x)
      implicit none
c     ^p_ij
      double precision x
      integer i,j
      include "var.inc"

      if((i.eq.0).and.(j.eq.0)) then
              hatps=0.d0
      elseif((i.eq.0).and.(j.eq.1)) then
              hatps=x*(1.d0-x)
      elseif((i.eq.1).and.(j.eq.0)) then
              hatps=4.d0/3.d0*x
      elseif((i.eq.1).and.(j.eq.1)) then
              hatps=4.d0/3.d0*(1.d0-x)
      else
              print *, "wrong splitting!"
      endif

      end function

      double precision function kbar(i,j,k,x)      
      implicit none
c     barK_ij, k=0(delta(1-x)), 1(regular), 2(plus,1/(1-x)),
c     3(plus,lnx/(1-x)), 4(plus,ln(1-x)/(1-x))
      double precision x, hatps, regps 
      integer i,j,k
      external hatps, regps
      include "var.inc"

      if((i.eq.0).and.(j.eq.0)) then

        if(k.eq.0) then
          kbar=-(11.d0/2.d0-nf/3.d0+67.d0/6.d0-pi**2/2.d0
     -        -5.d0*nf/9.d0-5.d0*pi**2/2.d0)
        elseif(k.eq.1) then
          kbar=dlog((1.d0-x)/x)*regps(i,j,x)+hatps(i,j,x)
        elseif(k.eq.2) then
          kbar=0.d0
        elseif(k.eq.3) then
          kbar=-6.d0
        elseif(k.eq.4) then
          kbar=6.d0
        else
                print *, "wrong splitting!"
        endif

      elseif((i.eq.1).and.(j.eq.1)) then

        if(k.eq.0) then
          kbar=-(2.d0+14.d0/3.d0-2.d0*pi**2/9.d0
     -        -10.d0*pi**2/9.d0)
        elseif(k.eq.1) then
          kbar=dlog((1.d0-x)/x)*regps(i,j,x)+hatps(i,j,x)
        elseif(k.eq.2) then
          kbar=0.d0
        elseif(k.eq.3) then
          kbar=-8.d0/3.d0
        elseif(k.eq.4) then
          kbar=8.d0/3.d0
        else
                print *, "wrong splitting!"
        endif

      elseif((i.eq.1).and.(j.eq.0)) then

        if(k.eq.0) then
          kbar=0.d0
        elseif(k.eq.1) then
          kbar=dlog((1.d0-x)/x)*regps(i,j,x)+hatps(i,j,x)
        elseif(k.eq.2) then
          kbar=0.d0
        elseif(k.eq.3) then
          kbar=0.d0
        elseif(k.eq.4) then
          kbar=0.d0
        else
                print *, "wrong splitting!"
        endif

      elseif((i.eq.0).and.(j.eq.1)) then

        if(k.eq.0) then
          kbar=0.d0
        elseif(k.eq.1) then
          kbar=dlog((1.d0-x)/x)*regps(i,j,x)+hatps(i,j,x)
        elseif(k.eq.2) then
          kbar=0.d0
        elseif(k.eq.3) then
          kbar=0.d0
        elseif(k.eq.4) then
          kbar=0.d0
        else
                print *, "wrong splitting!"
        endif

      else
              print *, "wrong splitting!"
      endif

      end function

      double precision function ktilde(i, j, k, x)
c K^tilde functions as defined in dipole formalism
      implicit none
      integer i, j, k
      double precision x, regps, NC, CF
      parameter (NC=3.d0, CF=4.d0/3.d0)
      external regps
      include "var.inc"

      ktilde=0.d0

      if((i.eq.0).and.(j.eq.0)) then
         if(k.eq.0) then
              ktilde=-pi**2/3.d0*NC
         elseif(k.eq.1) then
              ktilde=regps(i, j, x)*dlog(1.d0-x)    
         elseif(k.eq.2) then
              ktilde=0.d0
         elseif(k.eq.3) then
              ktilde=0.d0
         elseif(k.eq.4) then
              ktilde=2.d0*NC
         else 
             print *, "wrong splitting!"
         endif    
      elseif((i.eq.1).and.(j.eq.1)) then
         if(k.eq.0) then
              ktilde=-pi**2/3.d0*CF
         elseif(k.eq.1) then
              ktilde=regps(i, j, x)*dlog(1.d0-x)    
         elseif(k.eq.2) then
              ktilde=0.d0
         elseif(k.eq.3) then
              ktilde=0.d0
         elseif(k.eq.4) then
              ktilde=2.d0*CF
         else 
             print *, "wrong splitting!"
         endif    
      else    
         if(k.eq.0) then
              ktilde=0.d0
         elseif(k.eq.1) then
              ktilde=regps(i, j, x)*dlog(1.d0-x)    
         elseif(k.eq.2) then
              ktilde=0.d0
         elseif(k.eq.3) then
              ktilde=0.d0
         elseif(k.eq.4) then
              ktilde=0.d0
         else 
             print *, "wrong splitting!"
         endif    
      endif

      end function

      double precision function pplus(n,x)
c plus functions used
      implicit none
      double precision x
      integer n
      include "var.inc"

      if (n.eq.0) then
              pplus=1.d0
      elseif(n.eq.1) then
              pplus=1.d0
      elseif(n.eq.2) then
              pplus=1.d0/(1.d0-x)
      elseif(n.eq.3) then
              pplus=dlog(x)/(1.d0-x)
      elseif(n.eq.4) then
              pplus=dlog(1.d0-x)/(1.d0-x)
      else
              print *, "wrong plus!"
      endif

      end function
